from distutils.core import setup

setup(
    name = 'wenrenren-nester',
    version = '1.0.0',
    py_modules = ['wenrenren-nester'],
    author = 'jie',
    author_email = '632931651@qq.com',
    url = 'http://www.python.org/sigs/distutils-sig/',
    description = 'A simple printer of nested lists',
) # end of setup()